All notable changes to this project are documented in this file.

## [0.0.3] - 2023-03-18

### Added

- this changelog
- documentation of the existing code
- function ``awsmate.logger.log_internal_error()``

### Changed

- Almost all functions: Python naming convention applied to parameters
- Method ``awsmate.s3.LambdaNotificationEvent.object_key()``: corrected a typo in its name

### Deprecated

*nothing*

### Removed

*nothing*

### Fixed

*nothing*

### Security

*nothing*

## [0.0.2] and before - 2023-02-28

Genesis.

